@@ -164,13 +164,13 @@ def test_is_bogus():
         ('111.86.143.32',  False), # 111.86.143.32/27
 
         # will be added in Jan 2011
-        ('111.86.147.32',  True), # 111.86.147.32/27
-        ('111.86.147.64',  True), # 111.86.147.64/27
-        ('111.86.147.96',  True), # 111.86.147.96/27
-        ('111.86.147.128', True), # 111.86.147.128/27
-        ('111.86.147.160', True), # 111.86.147.160/27
-        ('111.86.147.192', True), # 111.86.147.192/27
-        ('111.86.147.224', True), # 111.86.147.224/27
+        ('111.86.147.32',  False), # 111.86.147.32/27
+        ('111.86.147.64',  False), # 111.86.147.64/27
+        ('111.86.147.96',  False), # 111.86.147.96/27
+        ('111.86.147.128', False), # 111.86.147.128/27
+        ('111.86.147.160', False), # 111.86.147.160/27
+        ('111.86.147.192', False), # 111.86.147.192/27
+        ('111.86.147.224', False), # 111.86.147.224/27
         ):
         yield func, ip, expected
 
